HttpExceptionConflict class

409 Conflict.

Inheritance

Constructors

HttpExceptionConflict({String message = "Conflict", Map<String, dynamic>? meta})
Creates a 409 Conflict exception.

Properties

hashCode int
The hash code for this object.
no setterinherited
message String
Human-readable description of the error.
finalinherited
meta Map<String, dynamic>?
Optional metadata associated with the error.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
stackTrace StackTrace
Captured stack trace at instantiation time.
finalinherited
status int
Status code associated with this HTTP exception.
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited