RadixResult<T> class
Result returned when resolving a path through the radix tree.
Constructors
-
RadixResult(T value, Map<
String, String> params) -
Creates a lookup result with the matched
valueandparams.
Properties
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited